@@ -1,7 +1,7 @@
 package App::SahUtils;
 
-our $DATE = '2020-02-12'; # DATE
-our $VERSION = '0.477'; # VERSION
+our $DATE = '2021-07-27'; # DATE
+our $VERSION = '0.478'; # VERSION
 
 use 5.010001;
 use strict;
@@ -346,7 +346,7 @@ App::SahUtils - Collection of CLI utilities for Sah and Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.477 of App::SahUtils (from Perl distribution App-SahUtils), released on 2020-02-12.
+This document describes version 0.478 of App::SahUtils (from Perl distribution App-SahUtils), released on 2021-07-27.
 
 =head1 SYNOPSIS
 
@@ -418,7 +418,7 @@ L<Sah> and L<Data::Sah>:
 
 Usage:
 
- get_sah_type(%args) -> [status, msg, payload, meta]
+ get_sah_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Extract type from a Sah string or array schema.
 
@@ -438,12 +438,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -453,7 +453,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_builtin_type(%args) -> [status, msg, payload, meta]
+ is_sah_builtin_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah builtin type.
 
@@ -473,12 +473,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -488,7 +488,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_collection_builtin_type(%args) -> [status, msg, payload, meta]
+ is_sah_collection_builtin_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah collection builtin type.
 
@@ -508,12 +508,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -523,7 +523,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_collection_type(%args) -> [status, msg, payload, meta]
+ is_sah_collection_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a collection Sah type.
 
@@ -544,12 +544,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -559,7 +559,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_numeric_builtin_type(%args) -> [status, msg, payload, meta]
+ is_sah_numeric_builtin_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah numeric builtin type.
 
@@ -579,12 +579,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -594,7 +594,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_numeric_type(%args) -> [status, msg, payload, meta]
+ is_sah_numeric_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a numeric Sah type.
 
@@ -615,12 +615,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -630,7 +630,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_ref_builtin_type(%args) -> [status, msg, payload, meta]
+ is_sah_ref_builtin_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah ref builtin type.
 
@@ -650,12 +650,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -665,7 +665,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_ref_type(%args) -> [status, msg, payload, meta]
+ is_sah_ref_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a ref Sah type.
 
@@ -686,12 +686,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -701,7 +701,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_simple_builtin_type(%args) -> [status, msg, payload, meta]
+ is_sah_simple_builtin_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah simple builtin type.
 
@@ -721,12 +721,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -736,7 +736,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_simple_type(%args) -> [status, msg, payload, meta]
+ is_sah_simple_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a simple Sah type.
 
@@ -757,12 +757,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -772,7 +772,7 @@ Return value:  (any)
 
 Usage:
 
- is_sah_type(%args) -> [status, msg, payload, meta]
+ is_sah_type(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check that a string or array schema is a Sah type.
 
@@ -793,12 +793,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -828,7 +828,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
